@@ -1,5 +1,5 @@
 use criterion::{black_box, criterion_group, criterion_main, Criterion};
-use ddex_builder::{DB_C14N, DeterminismConfig};
+use ddex_builder::{DeterminismConfig, DB_C14N};
 
 fn benchmark_canonicalization(c: &mut Criterion) {
     let xml = r#"<?xml version="1.0" encoding="UTF-8"?>
@@ -11,16 +11,16 @@ fn benchmark_canonicalization(c: &mut Criterion) {
 
     c.bench_function("canonicalize_small", |b| {
         let canonicalizer = DB_C14N::new(DeterminismConfig::default());
-        
+
         b.iter(|| {
             let result = canonicalizer.canonicalize(black_box(xml));
             black_box(result)
         });
     });
-    
+
     c.bench_function("canonical_hash", |b| {
         let canonicalizer = DB_C14N::new(DeterminismConfig::default());
-        
+
         b.iter(|| {
             let result = canonicalizer.canonical_hash(black_box(xml));
             black_box(result)
@@ -29,4 +29,4 @@ fn benchmark_canonicalization(c: &mut Criterion) {
 }
 
 criterion_group!(benches, benchmark_canonicalization);
-criterion_main!(benches);
\ No newline at end of file
+criterion_main!(benches);
