@@ -1,5 +1,5 @@
 //! Diff Comparison Example
-//! 
+//!
 //! This example demonstrates how to use the diff engine to compare DDEX releases,
 //! track changes, and generate detailed reports for release updates.
 
@@ -8,7 +8,7 @@ use std::error::Error;
 // Mock diff engine (in real implementation, these would be in the main library)
 mod diff_engine {
     use super::*;
-    
+
     #[derive(Clone)]
     pub struct DiffConfig {
         pub ignore_timestamps: bool,
@@ -17,24 +17,24 @@ mod diff_engine {
         pub include_technical_changes: bool,
         pub version_compatibility: VersionCompatibility,
     }
-    
+
     #[derive(Clone)]
     pub enum VersionCompatibility {
         Strict,
         Lenient,
     }
-    
+
     pub struct DiffEngine {
         config: DiffConfig,
     }
-    
+
     #[derive(Debug)]
     pub struct ChangeSet {
         pub changes: Vec<SemanticChange>,
         pub summary: String,
         pub impact_assessment: ImpactAssessment,
     }
-    
+
     #[derive(Debug)]
     pub struct SemanticChange {
         pub path: String,
@@ -44,7 +44,7 @@ mod diff_engine {
         pub impact: ImpactLevel,
         pub description: String,
     }
-    
+
     #[derive(Debug, PartialEq)]
     pub enum ChangeType {
         Added,
@@ -52,7 +52,7 @@ mod diff_engine {
         Removed,
         Moved,
     }
-    
+
     #[derive(Debug, PartialEq)]
     pub enum ImpactLevel {
         Low,
@@ -60,7 +60,7 @@ mod diff_engine {
         High,
         Critical,
     }
-    
+
     #[derive(Debug)]
     pub struct ImpactAssessment {
         pub overall_impact: ImpactLevel,
@@ -68,43 +68,47 @@ mod diff_engine {
         pub compatibility_score: f64,
         pub recommendations: Vec<String>,
     }
-    
+
     pub struct DiffFormatter;
-    
+
     impl DiffEngine {
         pub fn new(config: DiffConfig) -> Self {
             Self { config }
         }
-        
-        pub fn compare_releases(&self, original_xml: &str, updated_xml: &str) -> Result<ChangeSet, Box<dyn Error>> {
+
+        pub fn compare_releases(
+            &self,
+            original_xml: &str,
+            updated_xml: &str,
+        ) -> Result<ChangeSet, Box<dyn Error>> {
             let mut changes = Vec::new();
-            
+
             // Simulate diff analysis
             changes.extend(self.analyze_metadata_changes(original_xml, updated_xml));
             changes.extend(self.analyze_track_changes(original_xml, updated_xml));
             changes.extend(self.analyze_deal_changes(original_xml, updated_xml));
-            
+
             if self.config.include_technical_changes {
                 changes.extend(self.analyze_technical_changes(original_xml, updated_xml));
             }
-            
+
             let impact_assessment = self.assess_overall_impact(&changes);
             let summary = self.generate_summary(&changes, &impact_assessment);
-            
+
             Ok(ChangeSet {
                 changes,
                 summary,
                 impact_assessment,
             })
         }
-        
+
         fn analyze_metadata_changes(&self, original: &str, updated: &str) -> Vec<SemanticChange> {
             let mut changes = Vec::new();
-            
+
             // Check title changes
             if let (Some(old_title), Some(new_title)) = (
                 self.extract_element(original, "Title"),
-                self.extract_element(updated, "Title")
+                self.extract_element(updated, "Title"),
             ) {
                 if old_title != new_title {
                     changes.push(SemanticChange {
@@ -117,11 +121,11 @@ mod diff_engine {
                     });
                 }
             }
-            
+
             // Check artist changes
             if let (Some(old_artist), Some(new_artist)) = (
                 self.extract_element(original, "DisplayArtist"),
-                self.extract_element(updated, "DisplayArtist")
+                self.extract_element(updated, "DisplayArtist"),
             ) {
                 if old_artist != new_artist {
                     changes.push(SemanticChange {
@@ -134,11 +138,11 @@ mod diff_engine {
                     });
                 }
             }
-            
+
             // Check release date changes
             if let (Some(old_date), Some(new_date)) = (
                 self.extract_element(original, "ReleaseDate"),
-                self.extract_element(updated, "ReleaseDate")
+                self.extract_element(updated, "ReleaseDate"),
             ) {
                 if old_date != new_date {
                     changes.push(SemanticChange {
@@ -151,16 +155,16 @@ mod diff_engine {
                     });
                 }
             }
-            
+
             changes
         }
-        
+
         fn analyze_track_changes(&self, original: &str, updated: &str) -> Vec<SemanticChange> {
             let mut changes = Vec::new();
-            
+
             let original_track_count = original.matches("<SoundRecording>").count();
             let updated_track_count = updated.matches("<SoundRecording>").count();
-            
+
             if original_track_count != updated_track_count {
                 changes.push(SemanticChange {
                     path: "Resources/SoundRecordings".to_string(),
@@ -172,11 +176,13 @@ mod diff_engine {
                     old_value: Some(original_track_count.to_string()),
                     new_value: Some(updated_track_count.to_string()),
                     impact: ImpactLevel::High,
-                    description: format!("Track count changed from {} to {}", 
-                                       original_track_count, updated_track_count),
+                    description: format!(
+                        "Track count changed from {} to {}",
+                        original_track_count, updated_track_count
+                    ),
                 });
             }
-            
+
             // Check for ISRC changes
             if original.contains("ISRC>") && updated.contains("ISRC>") {
                 // Simulate ISRC comparison
@@ -191,17 +197,17 @@ mod diff_engine {
                     });
                 }
             }
-            
+
             changes
         }
-        
+
         fn analyze_deal_changes(&self, original: &str, updated: &str) -> Vec<SemanticChange> {
             let mut changes = Vec::new();
-            
+
             // Check territory changes
             if let (Some(old_territory), Some(new_territory)) = (
                 self.extract_element(original, "TerritoryCode"),
-                self.extract_element(updated, "TerritoryCode")
+                self.extract_element(updated, "TerritoryCode"),
             ) {
                 if old_territory != new_territory {
                     changes.push(SemanticChange {
@@ -214,11 +220,11 @@ mod diff_engine {
                     });
                 }
             }
-            
+
             // Check pricing changes
             if let (Some(old_price), Some(new_price)) = (
                 self.extract_element(original, "Price"),
-                self.extract_element(updated, "Price")
+                self.extract_element(updated, "Price"),
             ) {
                 if old_price != new_price {
                     changes.push(SemanticChange {
@@ -231,17 +237,17 @@ mod diff_engine {
                     });
                 }
             }
-            
+
             changes
         }
-        
+
         fn analyze_technical_changes(&self, original: &str, updated: &str) -> Vec<SemanticChange> {
             let mut changes = Vec::new();
-            
+
             // Check audio quality changes
             if let (Some(old_bitrate), Some(new_bitrate)) = (
                 self.extract_element(original, "BitRate"),
-                self.extract_element(updated, "BitRate")
+                self.extract_element(updated, "BitRate"),
             ) {
                 if old_bitrate != new_bitrate {
                     changes.push(SemanticChange {
@@ -254,11 +260,11 @@ mod diff_engine {
                     });
                 }
             }
-            
+
             // Check codec changes
             if let (Some(old_codec), Some(new_codec)) = (
                 self.extract_element(original, "Codec"),
-                self.extract_element(updated, "Codec")
+                self.extract_element(updated, "Codec"),
             ) {
                 if old_codec != new_codec {
                     changes.push(SemanticChange {
@@ -271,14 +277,14 @@ mod diff_engine {
                     });
                 }
             }
-            
+
             changes
         }
-        
+
         fn extract_element(&self, xml: &str, element_name: &str) -> Option<String> {
             let start_tag = format!("<{}>", element_name);
             let end_tag = format!("</{}>", element_name);
-            
+
             if let Some(start) = xml.find(&start_tag) {
                 if let Some(end) = xml.find(&end_tag) {
                     let content_start = start + start_tag.len();
@@ -289,13 +295,25 @@ mod diff_engine {
             }
             None
         }
-        
+
         fn assess_overall_impact(&self, changes: &[SemanticChange]) -> ImpactAssessment {
-            let critical_count = changes.iter().filter(|c| c.impact == ImpactLevel::Critical).count();
-            let high_count = changes.iter().filter(|c| c.impact == ImpactLevel::High).count();
-            let medium_count = changes.iter().filter(|c| c.impact == ImpactLevel::Medium).count();
-            let low_count = changes.iter().filter(|c| c.impact == ImpactLevel::Low).count();
-            
+            let critical_count = changes
+                .iter()
+                .filter(|c| c.impact == ImpactLevel::Critical)
+                .count();
+            let high_count = changes
+                .iter()
+                .filter(|c| c.impact == ImpactLevel::High)
+                .count();
+            let medium_count = changes
+                .iter()
+                .filter(|c| c.impact == ImpactLevel::Medium)
+                .count();
+            let low_count = changes
+                .iter()
+                .filter(|c| c.impact == ImpactLevel::Low)
+                .count();
+
             let overall_impact = if critical_count > 0 {
                 ImpactLevel::Critical
             } else if high_count > 0 {
@@ -305,7 +323,7 @@ mod diff_engine {
             } else {
                 ImpactLevel::Low
             };
-            
+
             let breaking_changes = critical_count + high_count;
             let non_breaking_changes = medium_count + low_count;
             let total_changes = changes.len();
@@ -314,22 +332,25 @@ mod diff_engine {
             } else {
                 100.0
             };
-            
+
             let mut recommendations = Vec::new();
-            
+
             if critical_count > 0 {
-                recommendations.push("Critical changes detected - verify downstream systems".to_string());
+                recommendations
+                    .push("Critical changes detected - verify downstream systems".to_string());
             }
             if high_count > 0 {
                 recommendations.push("High impact changes may affect user experience".to_string());
             }
             if breaking_changes > total_changes / 2 {
-                recommendations.push("Consider incremental rollout due to significant changes".to_string());
+                recommendations
+                    .push("Consider incremental rollout due to significant changes".to_string());
             }
             if compatibility_score < 70.0 {
-                recommendations.push("Low compatibility - thorough testing recommended".to_string());
+                recommendations
+                    .push("Low compatibility - thorough testing recommended".to_string());
             }
-            
+
             ImpactAssessment {
                 overall_impact,
                 breaking_changes,
@@ -337,8 +358,12 @@ mod diff_engine {
                 recommendations,
             }
         }
-        
-        fn generate_summary(&self, changes: &[SemanticChange], impact: &ImpactAssessment) -> String {
+
+        fn generate_summary(
+            &self,
+            changes: &[SemanticChange],
+            impact: &ImpactAssessment,
+        ) -> String {
             format!(
                 "Found {} changes with {} impact. {} breaking changes detected. Compatibility score: {:.1}%",
                 changes.len(),
@@ -353,20 +378,23 @@ mod diff_engine {
             )
         }
     }
-    
+
     impl DiffFormatter {
         pub fn new() -> Self {
             Self
         }
-        
-        pub fn format_human_readable(&self, changeset: &ChangeSet) -> Result<String, Box<dyn Error>> {
+
+        pub fn format_human_readable(
+            &self,
+            changeset: &ChangeSet,
+        ) -> Result<String, Box<dyn Error>> {
             let mut output = String::new();
-            
+
             output.push_str("📊 DDEX Release Comparison Report\n");
             output.push_str("================================\n\n");
-            
+
             output.push_str(&format!("📋 Summary: {}\n\n", changeset.summary));
-            
+
             output.push_str("🔍 Changes Detected:\n");
             for (i, change) in changeset.changes.iter().enumerate() {
                 let impact_icon = match change.impact {
@@ -375,7 +403,7 @@ mod diff_engine {
                     ImpactLevel::Medium => "📝",
                     ImpactLevel::Low => "ℹ️",
                 };
-                
+
                 output.push_str(&format!(
                     "{}. {} {} ({})\n   Path: {}\n   Change: {} → {}\n   Description: {}\n\n",
                     i + 1,
@@ -398,22 +426,31 @@ mod diff_engine {
                     change.description
                 ));
             }
-            
+
             output.push_str("📈 Impact Assessment:\n");
-            output.push_str(&format!("   Overall Impact: {:?}\n", changeset.impact_assessment.overall_impact));
-            output.push_str(&format!("   Breaking Changes: {}\n", changeset.impact_assessment.breaking_changes));
-            output.push_str(&format!("   Compatibility Score: {:.1}%\n\n", changeset.impact_assessment.compatibility_score));
-            
+            output.push_str(&format!(
+                "   Overall Impact: {:?}\n",
+                changeset.impact_assessment.overall_impact
+            ));
+            output.push_str(&format!(
+                "   Breaking Changes: {}\n",
+                changeset.impact_assessment.breaking_changes
+            ));
+            output.push_str(&format!(
+                "   Compatibility Score: {:.1}%\n\n",
+                changeset.impact_assessment.compatibility_score
+            ));
+
             if !changeset.impact_assessment.recommendations.is_empty() {
                 output.push_str("💡 Recommendations:\n");
                 for rec in &changeset.impact_assessment.recommendations {
                     output.push_str(&format!("   • {}\n", rec));
                 }
             }
-            
+
             Ok(output)
         }
-        
+
         pub fn format_json(&self, changeset: &ChangeSet) -> Result<String, Box<dyn Error>> {
             // Simplified JSON format for example
             Ok(format!(
@@ -430,25 +467,32 @@ mod diff_engine {
                 changeset.impact_assessment.breaking_changes,
                 changeset.impact_assessment.compatibility_score,
                 changeset.impact_assessment.overall_impact,
-                changeset.changes.iter()
+                changeset
+                    .changes
+                    .iter()
                     .enumerate()
-                    .map(|(i, c)| format!(r#"    {{
+                    .map(|(i, c)| format!(
+                        r#"    {{
       "id": {},
       "path": "{}",
       "type": "{:?}",
       "impact": "{:?}",
       "description": "{}"
-    }}"#, i, c.path, c.change_type, c.impact, c.description))
+    }}"#,
+                        i, c.path, c.change_type, c.impact, c.description
+                    ))
                     .collect::<Vec<_>>()
                     .join(",\n")
             ))
         }
-        
+
         pub fn format_summary(&self, changeset: &ChangeSet) -> Result<String, Box<dyn Error>> {
-            Ok(format!("DDEX Diff: {} changes, {} breaking, {:.1}% compatible", 
-                     changeset.changes.len(),
-                     changeset.impact_assessment.breaking_changes,
-                     changeset.impact_assessment.compatibility_score))
+            Ok(format!(
+                "DDEX Diff: {} changes, {} breaking, {:.1}% compatible",
+                changeset.changes.len(),
+                changeset.impact_assessment.breaking_changes,
+                changeset.impact_assessment.compatibility_score
+            ))
         }
     }
 }
@@ -459,24 +503,24 @@ use diff_engine::*;
 async fn main() -> Result<(), Box<dyn Error>> {
     println!("🔍 DDEX Builder - Diff Comparison Example");
     println!("Comparing DDEX releases and analyzing changes...\n");
-    
+
     // Create original and updated releases
     println!("📝 Creating original release...");
     let original_release = create_original_release();
     println!("  Title: {}", original_release.title);
     println!("  Artist: {}", original_release.artist);
     println!("  Tracks: {}", original_release.tracks.len());
-    
+
     println!("\n📝 Creating updated release...");
     let updated_release = create_updated_release();
     println!("  Title: {}", updated_release.title);
     println!("  Artist: {}", updated_release.artist);
     println!("  Tracks: {}", updated_release.tracks.len());
-    
+
     // Generate XML for both releases (simplified for example)
     let original_xml = generate_mock_xml(&original_release);
     let updated_xml = generate_mock_xml(&updated_release);
-    
+
     // Configure diff engine
     let diff_config = DiffConfig {
         ignore_timestamps: true,
@@ -485,41 +529,41 @@ async fn main() -> Result<(), Box<dyn Error>> {
         include_technical_changes: true,
         version_compatibility: VersionCompatibility::Strict,
     };
-    
+
     let diff_engine = DiffEngine::new(diff_config);
-    
+
     println!("\n🔍 Analyzing differences...");
-    
+
     // Perform diff analysis
     let changeset = diff_engine.compare_releases(&original_xml, &updated_xml)?;
-    
+
     println!("✅ Diff analysis completed");
     println!("📊 Found {} changes", changeset.changes.len());
-    
+
     // Format and display results
     let formatter = DiffFormatter::new();
-    
+
     println!("\n{}", "=".repeat(60));
     println!("📄 HUMAN-READABLE REPORT");
     println!("{}", "=".repeat(60));
     let human_report = formatter.format_human_readable(&changeset)?;
     println!("{}", human_report);
-    
+
     // Save detailed JSON report
     let json_report = formatter.format_json(&changeset)?;
     std::fs::write("diff_report.json", &json_report)?;
     println!("💾 Detailed JSON report saved to: diff_report.json");
-    
+
     // Display summary
     let summary = formatter.format_summary(&changeset)?;
     println!("\n📋 Summary: {}", summary);
-    
+
     // Demonstrate different analysis scenarios
     println!("\n🎯 Analysis Scenarios:");
     demonstrate_version_compatibility_analysis(&original_xml, &updated_xml)?;
     demonstrate_incremental_diff_tracking().await?;
     demonstrate_impact_assessment(&changeset);
-    
+
     Ok(())
 }
 
@@ -573,25 +617,26 @@ fn create_original_release() -> MockRelease {
 
 fn create_updated_release() -> MockRelease {
     let mut updated = create_original_release();
-    
+
     // Make updates that will be detected by diff engine
     updated.title = "Digital Dreams (Deluxe Edition)".to_string(); // Title change
     updated.price = Some("12.99".to_string()); // Price change
     updated.territory = "Worldwide".to_string(); // Territory expansion
     updated.bitrate = "2822".to_string(); // Higher quality audio
-    
+
     // Add a new track
     updated.tracks.push(MockTrack {
         title: "Bonus Track".to_string(),
         isrc: "USFC12400003".to_string(),
         duration: "PT3M30S".to_string(),
     });
-    
+
     updated
 }
 
 fn generate_mock_xml(release: &MockRelease) -> String {
-    format!(r#"<?xml version="1.0" encoding="UTF-8"?>
+    format!(
+        r#"<?xml version="1.0" encoding="UTF-8"?>
 <NewReleaseMessage xmlns="http://ddex.net/xml/ern/43" MessageSchemaVersionId="ern/43">
     <MessageHeader>
         <MessageId>TEST_001</MessageId>
@@ -622,9 +667,12 @@ fn generate_mock_xml(release: &MockRelease) -> String {
         release.label,
         release.release_date,
         release.genre,
-        release.tracks.iter()
+        release
+            .tracks
+            .iter()
             .enumerate()
-            .map(|(i, track)| format!(r#"
+            .map(|(i, track)| format!(
+                r#"
         <SoundRecording>
             <ResourceId>SR{:03}</ResourceId>
             <Title>{}</Title>
@@ -634,16 +682,26 @@ fn generate_mock_xml(release: &MockRelease) -> String {
                 <BitRate>{}</BitRate>
                 <Codec>{}</Codec>
             </TechnicalDetails>
-        </SoundRecording>"#, i + 1, track.title, track.isrc, track.duration, release.bitrate, release.codec))
+        </SoundRecording>"#,
+                i + 1,
+                track.title,
+                track.isrc,
+                track.duration,
+                release.bitrate,
+                release.codec
+            ))
             .collect::<String>(),
         release.territory,
         release.price.as_deref().unwrap_or("0.00")
     )
 }
 
-fn demonstrate_version_compatibility_analysis(original_xml: &str, updated_xml: &str) -> Result<(), Box<dyn Error>> {
+fn demonstrate_version_compatibility_analysis(
+    original_xml: &str,
+    updated_xml: &str,
+) -> Result<(), Box<dyn Error>> {
     println!("🔄 Version Compatibility Analysis:");
-    
+
     // Strict compatibility analysis
     let strict_config = DiffConfig {
         ignore_timestamps: true,
@@ -652,12 +710,15 @@ fn demonstrate_version_compatibility_analysis(original_xml: &str, updated_xml: &
         include_technical_changes: true,
         version_compatibility: VersionCompatibility::Strict,
     };
-    
+
     let strict_engine = DiffEngine::new(strict_config);
     let strict_changeset = strict_engine.compare_releases(original_xml, updated_xml)?;
-    
-    println!("  📊 Strict Analysis: {} changes detected", strict_changeset.changes.len());
-    
+
+    println!(
+        "  📊 Strict Analysis: {} changes detected",
+        strict_changeset.changes.len()
+    );
+
     // Lenient compatibility analysis
     let lenient_config = DiffConfig {
         ignore_timestamps: true,
@@ -666,28 +727,34 @@ fn demonstrate_version_compatibility_analysis(original_xml: &str, updated_xml: &
         include_technical_changes: false, // Ignore technical changes
         version_compatibility: VersionCompatibility::Lenient,
     };
-    
+
     let lenient_engine = DiffEngine::new(lenient_config);
     let lenient_changeset = lenient_engine.compare_releases(original_xml, updated_xml)?;
-    
-    println!("  📊 Lenient Analysis: {} changes detected", lenient_changeset.changes.len());
-    
+
+    println!(
+        "  📊 Lenient Analysis: {} changes detected",
+        lenient_changeset.changes.len()
+    );
+
     let compatibility_difference = strict_changeset.changes.len() - lenient_changeset.changes.len();
     if compatibility_difference > 0 {
-        println!("  ⚠️  {} additional changes detected in strict mode", compatibility_difference);
+        println!(
+            "  ⚠️  {} additional changes detected in strict mode",
+            compatibility_difference
+        );
     } else {
         println!("  ✅ Both analyses found similar results");
     }
-    
+
     Ok(())
 }
 
 async fn demonstrate_incremental_diff_tracking() -> Result<(), Box<dyn Error>> {
     println!("📈 Incremental Diff Tracking:");
-    
+
     let mut current_release = create_original_release();
     let mut previous_xml = generate_mock_xml(&current_release);
-    
+
     let diff_config = DiffConfig {
         ignore_timestamps: true,
         ignore_message_ids: false,
@@ -695,10 +762,10 @@ async fn demonstrate_incremental_diff_tracking() -> Result<(), Box<dyn Error>> {
         include_technical_changes: true,
         version_compatibility: VersionCompatibility::Strict,
     };
-    
+
     let diff_engine = DiffEngine::new(diff_config);
     let mut total_changes = 0;
-    
+
     // Simulate incremental updates
     for version in 1..=3 {
         // Make incremental changes
@@ -717,45 +784,70 @@ async fn demonstrate_incremental_diff_tracking() -> Result<(), Box<dyn Error>> {
             }
             _ => {}
         }
-        
+
         let current_xml = generate_mock_xml(&current_release);
         let changeset = diff_engine.compare_releases(&previous_xml, &current_xml)?;
-        
+
         println!("    🔍 Changes detected: {}", changeset.changes.len());
         total_changes += changeset.changes.len();
-        
+
         previous_xml = current_xml;
     }
-    
+
     println!("  📊 Total incremental changes tracked: {}", total_changes);
-    
+
     Ok(())
 }
 
 fn demonstrate_impact_assessment(changeset: &ChangeSet) {
     println!("⚖️  Impact Assessment:");
-    
-    let critical = changeset.changes.iter().filter(|c| c.impact == ImpactLevel::Critical).count();
-    let high = changeset.changes.iter().filter(|c| c.impact == ImpactLevel::High).count();
-    let medium = changeset.changes.iter().filter(|c| c.impact == ImpactLevel::Medium).count();
-    let low = changeset.changes.iter().filter(|c| c.impact == ImpactLevel::Low).count();
-    
+
+    let critical = changeset
+        .changes
+        .iter()
+        .filter(|c| c.impact == ImpactLevel::Critical)
+        .count();
+    let high = changeset
+        .changes
+        .iter()
+        .filter(|c| c.impact == ImpactLevel::High)
+        .count();
+    let medium = changeset
+        .changes
+        .iter()
+        .filter(|c| c.impact == ImpactLevel::Medium)
+        .count();
+    let low = changeset
+        .changes
+        .iter()
+        .filter(|c| c.impact == ImpactLevel::Low)
+        .count();
+
     println!("  🚨 Critical: {} changes", critical);
     println!("  ⚠️  High: {} changes", high);
     println!("  📝 Medium: {} changes", medium);
     println!("  ℹ️  Low: {} changes", low);
-    
-    println!("  📊 Overall Impact: {:?}", changeset.impact_assessment.overall_impact);
-    println!("  💔 Breaking Changes: {}", changeset.impact_assessment.breaking_changes);
-    println!("  🎯 Compatibility Score: {:.1}%", changeset.impact_assessment.compatibility_score);
-    
+
+    println!(
+        "  📊 Overall Impact: {:?}",
+        changeset.impact_assessment.overall_impact
+    );
+    println!(
+        "  💔 Breaking Changes: {}",
+        changeset.impact_assessment.breaking_changes
+    );
+    println!(
+        "  🎯 Compatibility Score: {:.1}%",
+        changeset.impact_assessment.compatibility_score
+    );
+
     if !changeset.impact_assessment.recommendations.is_empty() {
         println!("  💡 Recommendations:");
         for rec in &changeset.impact_assessment.recommendations {
             println!("    • {}", rec);
         }
     }
-    
+
     // Risk assessment
     let risk_level = if critical > 0 {
         "🔴 HIGH RISK"
@@ -766,9 +858,9 @@ fn demonstrate_impact_assessment(changeset: &ChangeSet) {
     } else {
         "✅ MINIMAL RISK"
     };
-    
+
     println!("  🎯 Risk Level: {}", risk_level);
-    
+
     // Deployment recommendations
     match changeset.impact_assessment.overall_impact {
         ImpactLevel::Critical => {
@@ -789,35 +881,35 @@ fn demonstrate_impact_assessment(changeset: &ChangeSet) {
 #[cfg(test)]
 mod tests {
     use super::*;
-    
+
     #[test]
     fn test_mock_release_creation() {
         let original = create_original_release();
         let updated = create_updated_release();
-        
+
         assert_ne!(original.title, updated.title);
         assert_ne!(original.price, updated.price);
         assert_ne!(original.tracks.len(), updated.tracks.len());
     }
-    
-    #[test] 
+
+    #[test]
     fn test_xml_generation() {
         let release = create_original_release();
         let xml = generate_mock_xml(&release);
-        
+
         assert!(xml.contains(&release.title));
         assert!(xml.contains(&release.artist));
         assert!(xml.contains("ISRC"));
     }
-    
+
     #[tokio::test]
     async fn test_diff_engine() {
         let original = create_original_release();
         let updated = create_updated_release();
-        
+
         let original_xml = generate_mock_xml(&original);
         let updated_xml = generate_mock_xml(&updated);
-        
+
         let config = DiffConfig {
             ignore_timestamps: true,
             ignore_message_ids: false,
@@ -825,11 +917,13 @@ mod tests {
             include_technical_changes: true,
             version_compatibility: VersionCompatibility::Strict,
         };
-        
+
         let engine = DiffEngine::new(config);
-        let changeset = engine.compare_releases(&original_xml, &updated_xml).unwrap();
-        
+        let changeset = engine
+            .compare_releases(&original_xml, &updated_xml)
+            .unwrap();
+
         assert!(!changeset.changes.is_empty());
         assert!(changeset.changes.len() >= 3); // Title, price, territory changes minimum
     }
-}
\ No newline at end of file
+}
