@@ -1,21 +1,20 @@
 //! Caching optimizations for DDEX Builder
-//! 
+//!
 //! This module provides multi-level caching for schemas, validation results,
 //! hash computations, and compiled templates to eliminate redundant work.
 
 use crate::error::BuildError;
 use crate::optimized_strings::OptimizedString;
+use blake3::Hasher as Blake3Hasher;
 use indexmap::IndexMap;
+use once_cell::sync::Lazy;
 use std::hash::{Hash, Hasher};
 use std::sync::{Arc, RwLock};
 use std::time::{Duration, Instant};
-use once_cell::sync::Lazy;
-use blake3::Hasher as Blake3Hasher;
 
 /// Global cache instance for schema and validation data
-static GLOBAL_CACHE: Lazy<Arc<RwLock<GlobalCache>>> = Lazy::new(|| {
-    Arc::new(RwLock::new(GlobalCache::new()))
-});
+static GLOBAL_CACHE: Lazy<Arc<RwLock<GlobalCache>>> =
+    Lazy::new(|| Arc::new(RwLock::new(GlobalCache::new())));
 
 /// Multi-level cache for DDEX Builder operations
 #[derive(Debug)]
@@ -43,7 +42,7 @@ impl GlobalCache {
             stats: CacheStats::default(),
         }
     }
-    
+
     /// Clear all caches
     pub fn clear_all(&mut self) {
         self.schemas.clear();
@@ -52,12 +51,12 @@ impl GlobalCache {
         self.template_cache.clear();
         self.stats = CacheStats::default();
     }
-    
+
     /// Get cache statistics
     pub fn stats(&self) -> &CacheStats {
         &self.stats
     }
-    
+
     /// Prune expired entries from all caches
     pub fn prune_expired(&mut self) {
         self.validation_cache.prune_expired();
@@ -83,7 +82,7 @@ impl SchemaCache {
             metadata: IndexMap::new(),
         }
     }
-    
+
     /// Get or compile a schema
     pub fn get_or_compile(
         &mut self,
@@ -95,33 +94,39 @@ impl SchemaCache {
             version: version.to_string(),
             profile: profile.map(|p| p.to_string()),
         };
-        
+
         if !self.schemas.contains_key(&key) {
             let start_time = Instant::now();
             let schema = compiler()?;
             let compile_time = start_time.elapsed();
-            
-            self.metadata.insert(key.clone(), SchemaMetadata {
-                compile_time,
-                last_used: Instant::now(),
-                use_count: 0,
-            });
-            
-            self.schemas.insert(key.clone(), CachedSchema {
-                schema,
-                created_at: Instant::now(),
-            });
+
+            self.metadata.insert(
+                key.clone(),
+                SchemaMetadata {
+                    compile_time,
+                    last_used: Instant::now(),
+                    use_count: 0,
+                },
+            );
+
+            self.schemas.insert(
+                key.clone(),
+                CachedSchema {
+                    schema,
+                    created_at: Instant::now(),
+                },
+            );
         }
-        
+
         // Update usage statistics
         if let Some(metadata) = self.metadata.get_mut(&key) {
             metadata.last_used = Instant::now();
             metadata.use_count += 1;
         }
-        
+
         Ok(&self.schemas.get(&key).unwrap().schema)
     }
-    
+
     /// Check if schema is cached
     pub fn contains(&self, version: &str, profile: Option<&str>) -> bool {
         let key = SchemaKey {
@@ -130,16 +135,17 @@ impl SchemaCache {
         };
         self.schemas.contains_key(&key)
     }
-    
+
     /// Clear all schemas
     pub fn clear(&mut self) {
         self.schemas.clear();
         self.metadata.clear();
     }
-    
+
     /// Get memory usage
     pub fn memory_usage(&self) -> usize {
-        self.schemas.values()
+        self.schemas
+            .values()
             .map(|cached| cached.schema.memory_footprint())
             .sum()
     }
@@ -154,6 +160,7 @@ struct SchemaKey {
 
 /// Cached schema with metadata
 #[derive(Debug)]
+#[allow(dead_code)]
 struct CachedSchema {
     schema: CompiledSchema,
     created_at: Instant,
@@ -161,6 +168,7 @@ struct CachedSchema {
 
 /// Schema metadata for statistics
 #[derive(Debug)]
+#[allow(dead_code)]
 struct SchemaMetadata {
     compile_time: Duration,
     last_used: Instant,
@@ -185,38 +193,57 @@ pub struct CompiledSchema {
 impl CompiledSchema {
     /// Calculate memory footprint
     pub fn memory_footprint(&self) -> usize {
-        std::mem::size_of::<Self>() + 
-        self.version.len() +
-        self.profile.as_ref().map_or(0, |p| p.len()) +
-        self.rules.len() * std::mem::size_of::<ValidationRule>() +
-        self.required_elements.iter().map(|e| e.len()).sum::<usize>() +
-        self.element_constraints.keys().map(|k| k.len()).sum::<usize>()
+        std::mem::size_of::<Self>()
+            + self.version.len()
+            + self.profile.as_ref().map_or(0, |p| p.len())
+            + self.rules.len() * std::mem::size_of::<ValidationRule>()
+            + self
+                .required_elements
+                .iter()
+                .map(|e| e.len())
+                .sum::<usize>()
+            + self
+                .element_constraints
+                .keys()
+                .map(|k| k.len())
+                .sum::<usize>()
     }
 }
 
-/// Validation rule
+/// Validation rule for cached schemas
 #[derive(Debug, Clone)]
 pub struct ValidationRule {
+    /// Path to element being validated
     pub element_path: String,
+    /// Type of validation rule
     pub rule_type: RuleType,
+    /// Rule parameters
     pub parameters: Vec<String>,
 }
 
-/// Rule types
+/// Type of validation rule
 #[derive(Debug, Clone)]
 pub enum RuleType {
+    /// Field is required
     Required,
+    /// Must match pattern
     Pattern(String),
+    /// Numeric range
     Range(f64, f64),
+    /// String length range
     Length(usize, usize),
+    /// Custom validation
     Custom(String),
 }
 
-/// Element constraint
+/// Schema constraints
 #[derive(Debug, Clone)]
 pub struct ElementConstraint {
+    /// Minimum occurrences
     pub min_occurs: usize,
+    /// Maximum occurrences (None = unbounded)
     pub max_occurs: Option<usize>,
+    /// Data type name
     pub data_type: String,
 }
 
@@ -237,16 +264,16 @@ impl ValidationCache {
             config: ValidationCacheConfig::default(),
         }
     }
-    
+
     /// Get cached validation result
     pub fn get(&mut self, content_hash: &str) -> Option<ValidationResult> {
         if let Some(cached) = self.results.get_mut(content_hash) {
             // Check if expired
             if cached.created_at.elapsed() > self.config.ttl {
-                self.results.remove(content_hash);
+                self.results.shift_remove(content_hash);
                 return None;
             }
-            
+
             cached.last_accessed = Instant::now();
             cached.access_count += 1;
             Some(cached.result.clone())
@@ -254,49 +281,57 @@ impl ValidationCache {
             None
         }
     }
-    
+
     /// Cache validation result
     pub fn insert(&mut self, content_hash: String, result: ValidationResult) {
         // Evict old entries if cache is full
         if self.results.len() >= self.config.max_entries {
             self.evict_lru();
         }
-        
-        self.results.insert(content_hash, CachedValidationResult {
-            result,
-            created_at: Instant::now(),
-            last_accessed: Instant::now(),
-            access_count: 0,
-        });
+
+        self.results.insert(
+            content_hash,
+            CachedValidationResult {
+                result,
+                created_at: Instant::now(),
+                last_accessed: Instant::now(),
+                access_count: 0,
+            },
+        );
     }
-    
+
     /// Evict least recently used entry
     fn evict_lru(&mut self) {
-        if let Some((key, _)) = self.results.iter()
+        if let Some((key, _)) = self
+            .results
+            .iter()
             .min_by_key(|(_, cached)| cached.last_accessed)
             .map(|(k, v)| (k.clone(), v.last_accessed))
         {
-            self.results.remove(&key);
+            self.results.shift_remove(&key);
         }
     }
-    
+
     /// Prune expired entries
     pub fn prune_expired(&mut self) {
         let ttl = self.config.ttl;
-        self.results.retain(|_, cached| cached.created_at.elapsed() <= ttl);
+        self.results
+            .retain(|_, cached| cached.created_at.elapsed() <= ttl);
     }
-    
+
     /// Clear all validation results
     pub fn clear(&mut self) {
         self.results.clear();
     }
-    
+
     /// Get cache hit rate
     pub fn hit_rate(&self) -> f64 {
         if self.results.is_empty() {
             0.0
         } else {
-            let total_accesses: usize = self.results.values()
+            let total_accesses: usize = self
+                .results
+                .values()
                 .map(|cached| cached.access_count)
                 .sum();
             if total_accesses == 0 {
@@ -336,9 +371,13 @@ impl Default for ValidationCacheConfig {
 /// Validation result
 #[derive(Debug, Clone)]
 pub struct ValidationResult {
+    /// Whether validation passed
     pub is_valid: bool,
+    /// List of errors
     pub errors: Vec<String>,
+    /// List of warnings
     pub warnings: Vec<String>,
+    /// Time taken to validate
     pub validation_time: Duration,
 }
 
@@ -359,7 +398,7 @@ impl HashCache {
             config: HashCacheConfig::default(),
         }
     }
-    
+
     /// Get or compute hash
     pub fn get_or_compute<T: Hash>(
         &mut self,
@@ -373,40 +412,44 @@ impl HashCache {
                 return cached.hash.clone();
             } else {
                 // Expired, remove and recompute
-                self.hashes.remove(key);
+                self.hashes.shift_remove(key);
             }
         }
-        
+
         // Compute new hash
         let hash = hasher_fn(value);
-        
+
         // Evict if necessary
         if self.hashes.len() >= self.config.max_entries {
             self.evict_random();
         }
-        
-        self.hashes.insert(key.clone(), CachedHash {
-            hash: hash.clone(),
-            created_at: Instant::now(),
-            access_count: 1,
-        });
-        
+
+        self.hashes.insert(
+            key.clone(),
+            CachedHash {
+                hash: hash.clone(),
+                created_at: Instant::now(),
+                access_count: 1,
+            },
+        );
+
         hash
     }
-    
+
     /// Evict a random entry (simple eviction strategy)
     fn evict_random(&mut self) {
         if let Some(key) = self.hashes.keys().next().cloned() {
-            self.hashes.remove(&key);
+            self.hashes.shift_remove(&key);
         }
     }
-    
+
     /// Prune expired entries
     pub fn prune_expired(&mut self) {
         let ttl = self.config.ttl;
-        self.hashes.retain(|_, cached| cached.created_at.elapsed() <= ttl);
+        self.hashes
+            .retain(|_, cached| cached.created_at.elapsed() <= ttl);
     }
-    
+
     /// Clear all hashes
     pub fn clear(&mut self) {
         self.hashes.clear();
@@ -416,8 +459,11 @@ impl HashCache {
 /// Hash key for caching
 #[derive(Debug, Clone, PartialEq, Eq, Hash)]
 pub struct HashKey {
+    /// Hashing algorithm used (e.g., "SHA256", "BLAKE3")
     pub algorithm: String,
+    /// Type of content being hashed
     pub content_type: String,
+    /// Resulting content identifier hash
     pub content_id: String,
 }
 
@@ -462,7 +508,7 @@ impl TemplateCache {
             config: TemplateCacheConfig::default(),
         }
     }
-    
+
     /// Get or compile template
     pub fn get_or_compile(
         &mut self,
@@ -473,41 +519,47 @@ impl TemplateCache {
             if self.templates.len() >= self.config.max_entries {
                 self.evict_lru();
             }
-            
+
             let template = compiler();
-            self.templates.insert(key.clone(), CachedTemplate {
-                template,
-                created_at: Instant::now(),
-                last_used: Instant::now(),
-                use_count: 0,
-            });
+            self.templates.insert(
+                key.clone(),
+                CachedTemplate {
+                    template,
+                    created_at: Instant::now(),
+                    last_used: Instant::now(),
+                    use_count: 0,
+                },
+            );
         }
-        
+
         // Update usage
         if let Some(cached) = self.templates.get_mut(key) {
             cached.last_used = Instant::now();
             cached.use_count += 1;
         }
-        
+
         &self.templates.get(key).unwrap().template
     }
-    
+
     /// Evict least recently used template
     fn evict_lru(&mut self) {
-        if let Some((key, _)) = self.templates.iter()
+        if let Some((key, _)) = self
+            .templates
+            .iter()
             .min_by_key(|(_, cached)| cached.last_used)
             .map(|(k, v)| (k.clone(), v.last_used))
         {
-            self.templates.remove(&key);
+            self.templates.shift_remove(&key);
         }
     }
-    
+
     /// Prune expired templates
     pub fn prune_expired(&mut self) {
         let ttl = self.config.ttl;
-        self.templates.retain(|_, cached| cached.created_at.elapsed() <= ttl);
+        self.templates
+            .retain(|_, cached| cached.created_at.elapsed() <= ttl);
     }
-    
+
     /// Clear all templates
     pub fn clear(&mut self) {
         self.templates.clear();
@@ -517,8 +569,11 @@ impl TemplateCache {
 /// Template key
 #[derive(Debug, Clone, PartialEq, Eq, Hash)]
 pub struct TemplateKey {
+    /// Element type name
     pub element_type: String,
+    /// DDEX version string
     pub version: String,
+    /// Optional variant identifier
     pub variant: Option<String>,
 }
 
@@ -545,8 +600,10 @@ pub struct CompiledTemplate {
 /// Template part (static or dynamic)
 #[derive(Debug, Clone)]
 pub enum TemplatePart {
+    /// Static string value
     Static(OptimizedString),
-    Placeholder(String), // Field name
+    /// Placeholder for dynamic field name
+    Placeholder(String),
 }
 
 /// Template cache configuration
@@ -568,30 +625,42 @@ impl Default for TemplateCacheConfig {
 /// Cache statistics
 #[derive(Debug, Default, Clone)]
 pub struct CacheStats {
+    /// Schema cache hits
     pub schema_hits: usize,
+    /// Schema cache misses
     pub schema_misses: usize,
+    /// Validation cache hits
     pub validation_hits: usize,
+    /// Validation cache misses
     pub validation_misses: usize,
+    /// Hash cache hits
     pub hash_hits: usize,
+    /// Hash cache misses
     pub hash_misses: usize,
+    /// Template cache hits
     pub template_hits: usize,
+    /// Template cache misses
     pub template_misses: usize,
 }
 
 impl CacheStats {
     /// Calculate overall hit rate
     pub fn overall_hit_rate(&self) -> f64 {
-        let total_hits = self.schema_hits + self.validation_hits + self.hash_hits + self.template_hits;
-        let total_requests = total_hits + self.schema_misses + self.validation_misses + 
-                           self.hash_misses + self.template_misses;
-        
+        let total_hits =
+            self.schema_hits + self.validation_hits + self.hash_hits + self.template_hits;
+        let total_requests = total_hits
+            + self.schema_misses
+            + self.validation_misses
+            + self.hash_misses
+            + self.template_misses;
+
         if total_requests == 0 {
             0.0
         } else {
             total_hits as f64 / total_requests as f64
         }
     }
-    
+
     /// Get cache efficiency summary
     pub fn summary(&self) -> String {
         format!(
@@ -603,25 +672,41 @@ impl CacheStats {
             self.template_hit_rate() * 100.0,
         )
     }
-    
+
     fn schema_hit_rate(&self) -> f64 {
         let total = self.schema_hits + self.schema_misses;
-        if total == 0 { 0.0 } else { self.schema_hits as f64 / total as f64 }
+        if total == 0 {
+            0.0
+        } else {
+            self.schema_hits as f64 / total as f64
+        }
     }
-    
+
     fn validation_hit_rate(&self) -> f64 {
         let total = self.validation_hits + self.validation_misses;
-        if total == 0 { 0.0 } else { self.validation_hits as f64 / total as f64 }
+        if total == 0 {
+            0.0
+        } else {
+            self.validation_hits as f64 / total as f64
+        }
     }
-    
+
     fn hash_hit_rate(&self) -> f64 {
         let total = self.hash_hits + self.hash_misses;
-        if total == 0 { 0.0 } else { self.hash_hits as f64 / total as f64 }
+        if total == 0 {
+            0.0
+        } else {
+            self.hash_hits as f64 / total as f64
+        }
     }
-    
+
     fn template_hit_rate(&self) -> f64 {
         let total = self.template_hits + self.template_misses;
-        if total == 0 { 0.0 } else { self.template_hits as f64 / total as f64 }
+        if total == 0 {
+            0.0
+        } else {
+            self.template_hits as f64 / total as f64
+        }
     }
 }
 
@@ -633,17 +718,17 @@ impl CacheManager {
     pub fn stats() -> CacheStats {
         GLOBAL_CACHE.read().unwrap().stats().clone()
     }
-    
+
     /// Clear all global caches
     pub fn clear_all() {
         GLOBAL_CACHE.write().unwrap().clear_all();
     }
-    
+
     /// Prune expired entries
     pub fn prune_expired() {
         GLOBAL_CACHE.write().unwrap().prune_expired();
     }
-    
+
     /// Get schema from cache or compile
     pub fn get_schema(
         version: &str,
@@ -654,15 +739,20 @@ impl CacheManager {
         let schema = cache.schemas.get_or_compile(version, profile, compiler)?;
         Ok(schema.clone())
     }
-    
+
     /// Fast hash computation with caching
-    pub fn fast_hash<T: Hash + std::fmt::Debug>(algorithm: &str, content_type: &str, content_id: &str, value: &T) -> String {
+    pub fn fast_hash<T: Hash + std::fmt::Debug>(
+        algorithm: &str,
+        content_type: &str,
+        content_id: &str,
+        value: &T,
+    ) -> String {
         let key = HashKey {
             algorithm: algorithm.to_string(),
             content_type: content_type.to_string(),
             content_id: content_id.to_string(),
         };
-        
+
         let mut cache = GLOBAL_CACHE.write().unwrap();
         cache.hash_cache.get_or_compute(&key, value, |v| {
             match algorithm {
@@ -686,41 +776,43 @@ impl CacheManager {
 #[cfg(test)]
 mod tests {
     use super::*;
-    
+
     #[test]
     fn test_schema_cache() {
         let mut cache = SchemaCache::new();
-        
+
         // Test cache miss and compilation
-        let schema = cache.get_or_compile("4.3", None, || {
-            Ok(CompiledSchema {
-                version: "4.3".to_string(),
-                profile: None,
-                rules: vec![],
-                required_elements: vec!["MessageHeader".to_string()],
-                element_constraints: IndexMap::new(),
+        let schema = cache
+            .get_or_compile("4.3", None, || {
+                Ok(CompiledSchema {
+                    version: "4.3".to_string(),
+                    profile: None,
+                    rules: vec![],
+                    required_elements: vec!["MessageHeader".to_string()],
+                    element_constraints: IndexMap::new(),
+                })
             })
-        }).unwrap();
-        
+            .unwrap();
+
         assert_eq!(schema.version, "4.3");
         assert!(cache.contains("4.3", None));
-        
+
         // Test cache hit
-        let schema2 = cache.get_or_compile("4.3", None, || {
-            panic!("Should not compile again")
-        }).unwrap();
-        
+        let schema2 = cache
+            .get_or_compile("4.3", None, || panic!("Should not compile again"))
+            .unwrap();
+
         assert_eq!(schema2.version, "4.3");
     }
-    
+
     #[test]
     fn test_validation_cache() {
         let mut cache = ValidationCache::new();
         let hash = "test_hash".to_string();
-        
+
         // Cache miss
         assert!(cache.get(&hash).is_none());
-        
+
         // Insert result
         let result = ValidationResult {
             is_valid: true,
@@ -729,12 +821,12 @@ mod tests {
             validation_time: Duration::from_millis(10),
         };
         cache.insert(hash.clone(), result);
-        
+
         // Cache hit
         let cached = cache.get(&hash).unwrap();
         assert!(cached.is_valid);
     }
-    
+
     #[test]
     fn test_hash_cache() {
         let mut cache = HashCache::new();
@@ -743,35 +835,31 @@ mod tests {
             content_type: "track".to_string(),
             content_id: "T001".to_string(),
         };
-        
+
         let test_value = "test content";
-        
+
         // First computation
-        let hash1 = cache.get_or_compute(&key, &test_value, |v| {
-            format!("hash_{}", v)
-        });
-        
+        let hash1 = cache.get_or_compute(&key, &test_value, |v| format!("hash_{}", v));
+
         // Second computation (should be cached)
-        let hash2 = cache.get_or_compute(&key, &test_value, |_| {
-            panic!("Should not compute again")
-        });
-        
+        let hash2 = cache.get_or_compute(&key, &test_value, |_| panic!("Should not compute again"));
+
         assert_eq!(hash1, hash2);
         assert_eq!(hash1, "hash_test content");
     }
-    
+
     #[test]
     fn test_cache_manager() {
         CacheManager::clear_all();
         let stats = CacheManager::stats();
         assert_eq!(stats.overall_hit_rate(), 0.0);
-        
+
         // Test fast hash
         let hash1 = CacheManager::fast_hash("blake3", "test", "item1", &"content");
         let hash2 = CacheManager::fast_hash("blake3", "test", "item1", &"content");
         assert_eq!(hash1, hash2); // Should be cached
     }
-    
+
     #[test]
     fn test_template_cache() {
         let mut cache = TemplateCache::new();
@@ -780,27 +868,23 @@ mod tests {
             version: "4.3".to_string(),
             variant: None,
         };
-        
+
         // First access - compile template
-        let template = cache.get_or_compile(&key, || {
-            CompiledTemplate {
-                parts: vec![
-                    TemplatePart::Static(OptimizedString::new("<SoundRecording>")),
-                    TemplatePart::Placeholder("title".to_string()),
-                    TemplatePart::Static(OptimizedString::new("</SoundRecording>")),
-                ],
-                required_fields: vec!["title".to_string()],
-                estimated_size: 100,
-            }
+        let template = cache.get_or_compile(&key, || CompiledTemplate {
+            parts: vec![
+                TemplatePart::Static(OptimizedString::new("<SoundRecording>")),
+                TemplatePart::Placeholder("title".to_string()),
+                TemplatePart::Static(OptimizedString::new("</SoundRecording>")),
+            ],
+            required_fields: vec!["title".to_string()],
+            estimated_size: 100,
         });
-        
+
         assert_eq!(template.required_fields.len(), 1);
-        
+
         // Second access - should use cached
-        let template2 = cache.get_or_compile(&key, || {
-            panic!("Should not compile again")
-        });
-        
+        let template2 = cache.get_or_compile(&key, || panic!("Should not compile again"));
+
         assert_eq!(template2.required_fields.len(), 1);
     }
-}
\ No newline at end of file
+}
