@@ -137,16 +137,19 @@
 // All necessary imports are via super::* in submodules
 use crate::error::BuildError;
 use crate::presets::{DdexVersion, MessageProfile, PartnerPreset};
-use serde::{Serialize, Deserialize};
-use serde_json::{json, Value as JsonValue};
 use indexmap::IndexMap;
+use serde::{Deserialize, Serialize};
+use serde_json::{json, Value as JsonValue};
 
 mod generators;
-mod validation;
 mod types;
+mod validation;
 
 // Re-export public items from submodules - only what we need publicly
-pub use validation::{SchemaValidator, ValidationConfig as SchemaValidationConfig, ValidationResult as SchemaValidationResult};
+pub use validation::{
+    SchemaValidator, ValidationConfig as SchemaValidationConfig,
+    ValidationResult as SchemaValidationResult,
+};
 
 /// Main JSON Schema generator for DDEX models
 #[derive(Debug, Clone)]
@@ -156,6 +159,7 @@ pub struct SchemaGenerator {
     /// Message profile for constraints
     profile: MessageProfile,
     /// Partner preset for additional validation rules
+    #[allow(dead_code)]
     preset: Option<PartnerPreset>,
     /// Schema configuration
     config: SchemaConfig,
@@ -212,7 +216,10 @@ pub struct JsonSchema {
     #[serde(skip_serializing_if = "Option::is_none")]
     pub required: Option<Vec<String>>,
     /// Additional properties allowed
-    #[serde(rename = "additionalProperties", skip_serializing_if = "Option::is_none")]
+    #[serde(
+        rename = "additionalProperties",
+        skip_serializing_if = "Option::is_none"
+    )]
     pub additional_properties: Option<bool>,
     /// Array items schema
     #[serde(skip_serializing_if = "Option::is_none")]
@@ -330,9 +337,13 @@ impl SchemaGenerator {
             config: SchemaConfig::default(),
         }
     }
-    
+
     /// Create schema generator with preset
-    pub fn with_preset(version: DdexVersion, profile: MessageProfile, preset: PartnerPreset) -> Self {
+    pub fn with_preset(
+        version: DdexVersion,
+        profile: MessageProfile,
+        preset: PartnerPreset,
+    ) -> Self {
         Self {
             version,
             profile,
@@ -340,19 +351,19 @@ impl SchemaGenerator {
             config: SchemaConfig::default(),
         }
     }
-    
+
     /// Set schema configuration
     pub fn with_config(mut self, config: SchemaConfig) -> Self {
         self.config = config;
         self
     }
-    
+
     /// Generate complete JSON Schema for DDEX BuildRequest
     pub fn generate_build_request_schema(&self) -> Result<SchemaGenerationResult, BuildError> {
         let mut warnings = Vec::new();
-        
+
         let schema = self.build_request_schema(&mut warnings)?;
-        
+
         let metadata = SchemaMetadata {
             ddex_version: self.version,
             profile: self.profile,
@@ -362,20 +373,20 @@ impl SchemaGenerator {
             required_count: schema.required.as_ref().map(|r| r.len()).unwrap_or(0),
             complexity_score: self.calculate_complexity(&schema),
         };
-        
+
         Ok(SchemaGenerationResult {
             schema,
             metadata,
             warnings,
         })
     }
-    
+
     /// Generate schema for FlatRelease model
     pub fn generate_flat_release_schema(&self) -> Result<SchemaGenerationResult, BuildError> {
         let mut warnings = Vec::new();
-        
+
         let schema = self.flat_release_schema(&mut warnings)?;
-        
+
         let metadata = SchemaMetadata {
             ddex_version: self.version,
             profile: self.profile,
@@ -385,44 +396,63 @@ impl SchemaGenerator {
             required_count: schema.required.as_ref().map(|r| r.len()).unwrap_or(0),
             complexity_score: self.calculate_complexity(&schema),
         };
-        
+
         Ok(SchemaGenerationResult {
             schema,
             metadata,
             warnings,
         })
     }
-    
+
     /// Generate schema for all DDEX element types
     pub fn generate_complete_schema(&self) -> Result<SchemaGenerationResult, BuildError> {
         let mut warnings = Vec::new();
         let mut definitions = IndexMap::new();
-        
+
         // Generate schemas for all major DDEX types
-        definitions.insert("BuildRequest".to_string(), self.build_request_schema(&mut warnings)?);
-        definitions.insert("ReleaseRequest".to_string(), self.release_request_schema(&mut warnings)?);
-        definitions.insert("TrackRequest".to_string(), self.track_request_schema(&mut warnings)?);
-        definitions.insert("DealRequest".to_string(), self.deal_request_schema(&mut warnings)?);
-        definitions.insert("MessageHeader".to_string(), self.message_header_schema(&mut warnings)?);
-        
+        definitions.insert(
+            "BuildRequest".to_string(),
+            self.build_request_schema(&mut warnings)?,
+        );
+        definitions.insert(
+            "ReleaseRequest".to_string(),
+            self.release_request_schema(&mut warnings)?,
+        );
+        definitions.insert(
+            "TrackRequest".to_string(),
+            self.track_request_schema(&mut warnings)?,
+        );
+        definitions.insert(
+            "DealRequest".to_string(),
+            self.deal_request_schema(&mut warnings)?,
+        );
+        definitions.insert(
+            "MessageHeader".to_string(),
+            self.message_header_schema(&mut warnings)?,
+        );
+
         // Add common type definitions
         definitions.extend(self.common_type_definitions(&mut warnings)?);
-        
+
         let schema = JsonSchema {
             schema: self.schema_draft_url(),
             id: Some("https://ddex.net/schema/ern/builder".to_string()),
-            title: Some(format!("DDEX Builder Schema - ERN {} {}", 
-                self.version_string(), self.profile_string())),
+            title: Some(format!(
+                "DDEX Builder Schema - ERN {} {}",
+                self.version_string(),
+                self.profile_string()
+            )),
             description: Some(format!(
                 "Complete JSON Schema for DDEX Builder structures targeting ERN {} with {} profile",
-                self.version_string(), self.profile_string()
+                self.version_string(),
+                self.profile_string()
             )),
             schema_type: Some("object".to_string()),
             definitions: Some(definitions),
             additional_properties: Some(false),
             ..Default::default()
         };
-        
+
         let metadata = SchemaMetadata {
             ddex_version: self.version,
             profile: self.profile,
@@ -432,68 +462,70 @@ impl SchemaGenerator {
             required_count: 0, // Root schema doesn't have required fields
             complexity_score: self.calculate_complexity(&schema),
         };
-        
+
         Ok(SchemaGenerationResult {
             schema,
             metadata,
             warnings,
         })
     }
-    
+
     /// Generate TypeScript type definitions from schema
     pub fn generate_typescript_types(&self, schema: &JsonSchema) -> Result<String, BuildError> {
         let mut typescript = String::new();
-        
+
         typescript.push_str(&format!(
             "// Generated TypeScript types for DDEX Builder - ERN {} {}\n",
-            self.version_string(), self.profile_string()
+            self.version_string(),
+            self.profile_string()
         ));
         typescript.push_str("// Generated at: ");
         typescript.push_str(&chrono::Utc::now().to_rfc3339());
         typescript.push_str("\n\n");
-        
+
         if let Some(ref definitions) = schema.definitions {
             for (name, def_schema) in definitions {
                 typescript.push_str(&self.schema_to_typescript(name, def_schema)?);
                 typescript.push_str("\n\n");
             }
         }
-        
+
         Ok(typescript)
     }
-    
+
     /// Generate Python TypedDict definitions from schema
     pub fn generate_python_types(&self, schema: &JsonSchema) -> Result<String, BuildError> {
         let mut python = String::new();
-        
+
         python.push_str(&format!(
             "# Generated Python TypedDict types for DDEX Builder - ERN {} {}\n",
-            self.version_string(), self.profile_string()
+            self.version_string(),
+            self.profile_string()
         ));
         python.push_str("# Generated at: ");
         python.push_str(&chrono::Utc::now().to_rfc3339());
         python.push_str("\n\n");
         python.push_str("from typing import TypedDict, Optional, List, Union, Literal\nfrom datetime import datetime\n\n");
-        
+
         if let Some(ref definitions) = schema.definitions {
             for (name, def_schema) in definitions {
                 python.push_str(&self.schema_to_python(name, def_schema)?);
                 python.push_str("\n\n");
             }
         }
-        
+
         Ok(python)
     }
-    
+
     // Private helper methods
-    
+
     fn schema_draft_url(&self) -> String {
         match self.config.draft_version {
             SchemaDraft::Draft202012 => "https://json-schema.org/draft/2020-12/schema".to_string(),
             SchemaDraft::Draft07 => "https://json-schema.org/draft-07/schema".to_string(),
         }
     }
-    
+
     fn version_string(&self) -> &str {
         match self.version {
             DdexVersion::Ern43 => "4.3",
@@ -502,7 +534,7 @@ impl SchemaGenerator {
             DdexVersion::Ern382 => "3.8.2",
         }
     }
-    
+
     fn profile_string(&self) -> &str {
         match self.profile {
             MessageProfile::AudioAlbum => "AudioAlbum",
@@ -512,46 +544,58 @@ impl SchemaGenerator {
             MessageProfile::Mixed => "Mixed",
         }
     }
-    
+
     fn count_properties(&self, schema: &JsonSchema) -> usize {
         let mut count = 0;
-        
+
         if let Some(ref properties) = schema.properties {
             count += properties.len();
             for (_, prop_schema) in properties {
                 count += self.count_properties(prop_schema);
             }
         }
-        
+
         if let Some(ref definitions) = schema.definitions {
             for (_, def_schema) in definitions {
                 count += self.count_properties(def_schema);
             }
         }
-        
+
         count
     }
-    
+
     fn calculate_complexity(&self, schema: &JsonSchema) -> f64 {
         let mut complexity = 0.0;
-        
+
         // Base complexity for each property
         if let Some(ref properties) = schema.properties {
             complexity += properties.len() as f64;
-            
+
             for (_, prop_schema) in properties {
                 complexity += self.calculate_complexity(prop_schema) * 0.5;
             }
         }
-        
+
         // Add complexity for advanced features
-        if schema.all_of.is_some() { complexity += 2.0; }
-        if schema.any_of.is_some() { complexity += 3.0; }
-        if schema.one_of.is_some() { complexity += 4.0; }
-        if schema.if_schema.is_some() { complexity += 5.0; }
-        if schema.pattern.is_some() { complexity += 1.0; }
-        if schema.enum_values.is_some() { complexity += 0.5; }
-        
+        if schema.all_of.is_some() {
+            complexity += 2.0;
+        }
+        if schema.any_of.is_some() {
+            complexity += 3.0;
+        }
+        if schema.one_of.is_some() {
+            complexity += 4.0;
+        }
+        if schema.if_schema.is_some() {
+            complexity += 5.0;
+        }
+        if schema.pattern.is_some() {
+            complexity += 1.0;
+        }
+        if schema.enum_values.is_some() {
+            complexity += 0.5;
+        }
+
         complexity
     }
 }
@@ -620,72 +664,77 @@ impl SchemaCommand {
     pub fn execute(&self) -> Result<(), BuildError> {
         let version = self.parse_version()?;
         let profile = self.parse_profile()?;
-        
+
         let config = SchemaConfig {
             include_examples: self.examples,
             strict_validation: self.strict,
             ..Default::default()
         };
-        
+
         let generator = SchemaGenerator::new(version, profile).with_config(config);
         let result = generator.generate_complete_schema()?;
-        
+
         // Output JSON Schema
-        let schema_json = serde_json::to_string_pretty(&result.schema)
-            .map_err(|e| BuildError::InvalidFormat {
+        let schema_json = serde_json::to_string_pretty(&result.schema).map_err(|e| {
+            BuildError::InvalidFormat {
                 field: "schema".to_string(),
                 message: format!("Failed to serialize schema: {}", e),
-            })?;
-        
+            }
+        })?;
+
         if let Some(ref output_path) = self.output {
-            std::fs::write(output_path, &schema_json)
-                .map_err(|e| BuildError::InvalidFormat {
-                    field: "output".to_string(),
-                    message: format!("Failed to write schema: {}", e),
-                })?;
+            std::fs::write(output_path, &schema_json).map_err(|e| BuildError::InvalidFormat {
+                field: "output".to_string(),
+                message: format!("Failed to write schema: {}", e),
+            })?;
             println!("Schema written to: {}", output_path);
         } else {
             println!("{}", schema_json);
         }
-        
+
         // Generate TypeScript types if requested
         if self.typescript {
             let ts_types = generator.generate_typescript_types(&result.schema)?;
-            let ts_path = self.output.as_ref()
+            let ts_path = self
+                .output
+                .as_ref()
                 .map(|p| p.replace(".json", ".d.ts"))
                 .unwrap_or_else(|| "ddex-types.d.ts".to_string());
-            
-            std::fs::write(&ts_path, ts_types)
-                .map_err(|e| BuildError::InvalidFormat {
-                    field: "typescript".to_string(),
-                    message: format!("Failed to write TypeScript types: {}", e),
-                })?;
+
+            std::fs::write(&ts_path, ts_types).map_err(|e| BuildError::InvalidFormat {
+                field: "typescript".to_string(),
+                message: format!("Failed to write TypeScript types: {}", e),
+            })?;
             println!("TypeScript types written to: {}", ts_path);
         }
-        
+
         // Generate Python types if requested
         if self.python {
             let py_types = generator.generate_python_types(&result.schema)?;
-            let py_path = self.output.as_ref()
+            let py_path = self
+                .output
+                .as_ref()
                 .map(|p| p.replace(".json", ".py"))
                 .unwrap_or_else(|| "ddex_types.py".to_string());
-            
-            std::fs::write(&py_path, py_types)
-                .map_err(|e| BuildError::InvalidFormat {
-                    field: "python".to_string(),
-                    message: format!("Failed to write Python types: {}", e),
-                })?;
+
+            std::fs::write(&py_path, py_types).map_err(|e| BuildError::InvalidFormat {
+                field: "python".to_string(),
+                message: format!("Failed to write Python types: {}", e),
+            })?;
             println!("Python types written to: {}", py_path);
         }
-        
+
         // Print metadata
         println!("\nSchema Generation Complete:");
         println!("  DDEX Version: ERN {}", generator.version_string());
         println!("  Profile: {}", generator.profile_string());
         println!("  Properties: {}", result.metadata.property_count);
         println!("  Required Fields: {}", result.metadata.required_count);
-        println!("  Complexity Score: {:.1}", result.metadata.complexity_score);
-        
+        println!(
+            "  Complexity Score: {:.1}",
+            result.metadata.complexity_score
+        );
+
         if !result.warnings.is_empty() {
             println!("\nWarnings:");
             for warning in &result.warnings {
@@ -698,10 +747,10 @@ impl SchemaCommand {
                 }
             }
         }
-        
+
         Ok(())
     }
-    
+
     fn parse_version(&self) -> Result<DdexVersion, BuildError> {
         match self.version.as_str() {
             "4.3" | "43" => Ok(DdexVersion::Ern43),
@@ -714,7 +763,7 @@ impl SchemaCommand {
             }),
         }
     }
-    
+
     fn parse_profile(&self) -> Result<MessageProfile, BuildError> {
         match self.profile.to_lowercase().as_str() {
             "audioalbum" | "audio-album" => Ok(MessageProfile::AudioAlbum),
@@ -745,7 +794,7 @@ mod tests {
     #[test]
     fn test_schema_config_defaults() {
         let config = SchemaConfig::default();
-        
+
         assert!(matches!(config.draft_version, SchemaDraft::Draft202012));
         assert!(config.include_examples);
         assert!(config.include_descriptions);
@@ -758,20 +807,20 @@ mod tests {
     fn test_build_request_schema_generation() {
         let generator = SchemaGenerator::new(DdexVersion::Ern43, MessageProfile::AudioAlbum);
         let result = generator.generate_build_request_schema().unwrap();
-        
+
         assert!(result.schema.title.is_some());
         assert!(result.schema.schema_type == Some("object".to_string()));
         assert!(result.schema.properties.is_some());
         assert!(result.schema.required.is_some());
-        
+
         let properties = result.schema.properties.unwrap();
         assert!(properties.contains_key("header"));
         assert!(properties.contains_key("releases"));
-        
+
         let required = result.schema.required.unwrap();
         assert!(required.contains(&"header".to_string()));
         assert!(required.contains(&"releases".to_string()));
-        
+
         // Check metadata
         assert!(result.metadata.property_count > 0);
         assert!(result.metadata.complexity_score > 0.0);
@@ -781,9 +830,9 @@ mod tests {
     fn test_complete_schema_generation() {
         let generator = SchemaGenerator::new(DdexVersion::Ern43, MessageProfile::AudioAlbum);
         let result = generator.generate_complete_schema().unwrap();
-        
+
         assert!(result.schema.definitions.is_some());
-        
+
         let definitions = result.schema.definitions.unwrap();
         assert!(definitions.contains_key("BuildRequest"));
         assert!(definitions.contains_key("ReleaseRequest"));
@@ -793,9 +842,12 @@ mod tests {
         assert!(definitions.contains_key("LocalizedString"));
         assert!(definitions.contains_key("Party"));
         assert!(definitions.contains_key("DealTerms"));
-        
+
         // Verify schema structure
-        assert_eq!(result.schema.schema, "https://json-schema.org/draft/2020-12/schema");
+        assert_eq!(
+            result.schema.schema,
+            "https://json-schema.org/draft/2020-12/schema"
+        );
         assert!(result.schema.id.is_some());
         assert!(result.schema.title.is_some());
         assert!(result.schema.description.is_some());
@@ -806,7 +858,7 @@ mod tests {
         let generator_43 = SchemaGenerator::new(DdexVersion::Ern43, MessageProfile::AudioAlbum);
         let generator_42 = SchemaGenerator::new(DdexVersion::Ern42, MessageProfile::AudioAlbum);
         let generator_41 = SchemaGenerator::new(DdexVersion::Ern41, MessageProfile::AudioAlbum);
-        
+
         assert_eq!(generator_43.version_string(), "4.3");
         assert_eq!(generator_42.version_string(), "4.2");
         assert_eq!(generator_41.version_string(), "4.1");
@@ -819,7 +871,7 @@ mod tests {
         let video_album = SchemaGenerator::new(DdexVersion::Ern43, MessageProfile::VideoAlbum);
         let video_single = SchemaGenerator::new(DdexVersion::Ern43, MessageProfile::VideoSingle);
         let mixed = SchemaGenerator::new(DdexVersion::Ern43, MessageProfile::Mixed);
-        
+
         assert_eq!(audio_album.profile_string(), "AudioAlbum");
         assert_eq!(audio_single.profile_string(), "AudioSingle");
         assert_eq!(video_album.profile_string(), "VideoAlbum");
@@ -838,11 +890,11 @@ mod tests {
             examples: true,
             strict: true,
         };
-        
+
         let parsed_version = command.parse_version().unwrap();
         let parsed_profile = command.parse_profile().unwrap();
-        
+
         assert!(matches!(parsed_version, DdexVersion::Ern43));
         assert!(matches!(parsed_profile, MessageProfile::AudioAlbum));
     }
-}
\ No newline at end of file
+}
